@@ -85,19 +85,187 @@ try:
     from core.config_cache import get_cached_config, get_cached_spec_progress
 except ImportError:
     # Fallback to direct functions if cache not available
-    import yaml as yaml_fallback
+    # Try PyYAML first, then use simple parser
+    try:
+        import yaml as yaml_fallback
+
+        HAS_YAML_FALLBACK = True
+    except ImportError:
+        HAS_YAML_FALLBACK = False
+
+    def _simple_yaml_parse(content: str) -> dict:
+        """Simple YAML parser for basic key-value configs without PyYAML dependency.
+
+        Handles:
+        - Top-level keys with nested values
+        - String values (quoted or unquoted, including empty strings)
+        - Boolean values (true/false)
+        - Numeric values
+        - Comments (lines starting with # or inline after values)
+
+        Does NOT handle:
+        - Lists
+        - Complex nested structures beyond 2 levels
+        - Multi-line strings
+        """
+        result = {}
+        current_section = None
+        lines = content.split("\n")
+
+        for line in lines:
+            # Skip empty lines and comments
+            stripped = line.strip()
+            if not stripped or stripped.startswith("#"):
+                continue
+
+            # Count leading spaces for indentation
+            indent = len(line) - len(line.lstrip())
+
+            # Check if this is a key-value pair
+            if ":" in stripped:
+                key_part, _, value_part = stripped.partition(":")
+                key = key_part.strip()
+                value = value_part.strip()
+
+                # Track if value was explicitly quoted (including empty strings)
+                was_quoted = False
+
+                # Handle quoted strings first - extract value within quotes
+                if value.startswith('"'):
+                    # Find the closing quote
+                    close_quote = value.find('"', 1)
+                    if close_quote > 0:
+                        value = value[1:close_quote]
+                        was_quoted = True
+                    elif value == '""':
+                        # Handle explicit empty string ""
+                        value = ""
+                        was_quoted = True
+                elif value.startswith("'"):
+                    # Find the closing quote
+                    close_quote = value.find("'", 1)
+                    if close_quote > 0:
+                        value = value[1:close_quote]
+                        was_quoted = True
+                    elif value == "''":
+                        # Handle explicit empty string ''
+                        value = ""
+                        was_quoted = True
+                else:
+                    # Remove inline comments for unquoted values
+                    if "#" in value:
+                        value = value.split("#")[0].strip()
+
+                # Top-level key (no indentation or minimal indentation)
+                if indent == 0:
+                    if value or was_quoted:
+                        # Simple key: value (including empty quoted strings)
+                        result[key] = _parse_simple_value(value)
+                    else:
+                        # Section header (e.g., "user:", "language:")
+                        current_section = key
+                        result[current_section] = {}
+                elif current_section and indent > 0:
+                    # Nested key under current section
+                    if value or was_quoted:
+                        # Store value (including empty quoted strings)
+                        result[current_section][key] = _parse_simple_value(value)
+                    else:
+                        # Nested section (2-level nesting) - only when no value at all
+                        result[current_section][key] = {}
+
+        return result
+
+    def _parse_simple_value(value: str):
+        """Parse a simple value string into appropriate Python type."""
+        if not value:
+            return ""
+
+        # Boolean
+        if value.lower() == "true":
+            return True
+        if value.lower() == "false":
+            return False
+
+        # Numeric
+        try:
+            if "." in value:
+                return float(value)
+            return int(value)
+        except ValueError:
+            pass
+
+        return value
+
+    def _merge_configs(base: dict, override: dict) -> dict:
+        """Recursively merge two configuration dictionaries."""
+        result = base.copy()
+        for key, value in override.items():
+            if key in result and isinstance(result[key], dict) and isinstance(value, dict):
+                result[key] = _merge_configs(result[key], value)
+            else:
+                result[key] = value
+        return result
+
+    def _load_yaml_file(file_path: Path) -> dict:
+        """Load a YAML file using PyYAML or simple parser."""
+        if not file_path.exists():
+            return {}
+        try:
+            content = file_path.read_text(encoding="utf-8")
+            if HAS_YAML_FALLBACK:
+                return yaml_fallback.safe_load(content) or {}
+            else:
+                return _simple_yaml_parse(content)
+        except Exception:
+            return {}
 
     def get_cached_config():
-        # FIX: Use absolute path from find_project_root() to ensure correct directory
+        """Load config with section file merging for complete configuration.
+
+        FIX #245/#243: Properly loads both config.yaml AND section files,
+        merging them to provide complete configuration data.
+
+        Priority (highest to lowest):
+        1. Section files (.moai/config/sections/*.yaml)
+        2. Main config file (.moai/config/config.yaml)
+        """
         project_root = find_project_root()
-        config_path = project_root / ".moai" / "config" / "config.yaml"
-        if config_path.exists():
-            try:
-                return yaml_fallback.safe_load(config_path.read_text()) or {}
-            except (yaml_fallback.YAMLError, OSError, UnicodeDecodeError):
-                # YAML parsing, file read, or encoding errors
-                return None
-        return None
+        config_dir = project_root / ".moai" / "config"
+
+        # Start with main config file
+        main_config_path = config_dir / "config.yaml"
+        config = _load_yaml_file(main_config_path)
+
+        # If main config failed, try JSON fallback
+        if not config:
+            json_config_path = config_dir / "config.json"
+            if json_config_path.exists():
+                try:
+                    config = json.loads(json_config_path.read_text(encoding="utf-8"))
+                except (json.JSONDecodeError, OSError):
+                    config = {}
+
+        # Merge section files (they take priority for their specific keys)
+        sections_dir = config_dir / "sections"
+        if sections_dir.exists():
+            section_files = [
+                ("user.yaml", "user"),
+                ("language.yaml", "language"),
+                ("git-strategy.yaml", "git_strategy"),
+                ("project.yaml", "project"),
+                ("quality.yaml", "quality"),
+                ("system.yaml", "system"),
+            ]
+
+            for filename, key in section_files:
+                section_path = sections_dir / filename
+                section_data = _load_yaml_file(section_path)
+                if section_data:
+                    # Merge section data into config
+                    config = _merge_configs(config, section_data)
+
+        return config if config else None
 
     def get_cached_spec_progress():
         """Get SPEC progress information - FIXED to use YAML frontmatter parsing"""
@@ -150,7 +318,7 @@ def should_show_setup_messages() -> bool:
     """Determine whether to show setup completion messages (cached version).
 
     Logic:
-    1. Read .moai/config/config.json (using cache)
+    1. Read .moai/config/config.yaml (using cache)
     2. Check session.suppress_setup_messages flag
     3. If suppress_setup_messages is False, always show messages
     4. If suppress_setup_messages is True:
@@ -266,6 +434,8 @@ def get_git_info() -> Dict[str, Any]:
         # Define git commands to run in parallel
         git_commands = [
             (["git", "branch", "--show-current"], "branch"),
+            (["git", "rev-parse", "--abbrev-ref", "HEAD"], "head_ref"),
+            (["git", "rev-parse", "--short", "HEAD"], "head_commit"),
             (["git", "log", "--pretty=format:%h %s", "-1"], "last_commit"),
             (["git", "log", "--pretty=format:%ar", "-1"], "commit_time"),
             (["git", "status", "--porcelain"], "changes_raw"),
@@ -288,10 +458,16 @@ def get_git_info() -> Dict[str, Any]:
 
         # Process results with proper handling for empty values
         branch = results.get("branch", "")
+        head_ref = results.get("head_ref", "")
+        head_commit = results.get("head_commit", "")
         last_commit = results.get("last_commit", "")
 
-        # FIX #1: Handle empty branch (no commits yet)
-        if not branch:
+        # FIX: Detect detached HEAD state
+        if not branch and head_ref == "HEAD":
+            # Detached HEAD state - show commit hash
+            branch = f"HEAD detached at {head_commit}"
+        elif not branch:
+            # No commits yet
             branch = "No commits yet → Make your first commit"
 
         # FIX #4: Handle no commits case
@@ -722,11 +898,11 @@ def format_session_output() -> str:
         if personalization["is_korean"]:
             output.append(
                 "   👋 환영합니다! 프로젝트를 시작하기 전에 "
-                "'moai:0-project setting' 명령어로 사용자 이름과 설정을 구성해주세요"
+                "'/moai:0-project setting' 명령어로 사용자 이름과 설정을 구성해주세요"
             )
         else:
             output.append(
-                "   👋 Welcome! Before starting, please run 'moai:0-project setting' "
+                "   👋 Welcome! Before starting, please run '/moai:0-project setting' "
                 "to configure your name and project settings"
             )
     elif personalization["has_personalization"]:
